Author: John J. Lee <jjl@pobox.com>
Keywords: Python,HTML,HTTP,browser,stateful,web,client,client-side,mechanize,cookie,form,META,HTTP-EQUIV,Refresh,ClientForm,ClientCookie,pullparser,WWW::Mechanize
Date: 2011-03-31

# mechanize — Download

There is more than one way to obtain mechanize:

Note re Windows and Mac support: currently the tests are only routinely run on Ubuntu 9.10 (“karmic”). However, as far as I know, mechanize works fine on Windows and Mac platforms.

## easy_install

1. Install EasyInstall

2. `easy_install mechanize`

Easy install will automatically download the latest source code release and install it.

## Source code release

1. Download the source from one of the links below

2. Unpack the source distribution and change directory to the resulting top-level directory.

3. `python setup.py install`

This is a stable release.

- `mechanize-0.2.5.tar.gz`

- `mechanize-0.2.5.zip`

- Older versions. Note: these are hosted on sourceforge, which at the time of writing (2011–03–31) is returning invalid HTTP responses — you can also find old releases on PyPI)

All the documentation (these web pages, docstrings, and the changelog) is included in the distribution.

## git repository

The git repository is here. To check it out:

1. `git clone git://github.com/jjlee/mechanize.git`

I prefer questions and comments to be sent to the mailing list rather than direct to me.

John J. Lee, March 2011.